<?php

/**
 * @file
 * Contains \Drupal\simple_redirect\SimpleRedirectSubscriber.
 */

namespace Drupal\simple_redirect\EventSubscriber;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\HttpKernel\Event\GetResponseEvent;

/**
 * Class SimpleRedirectSubscriber.
 *
 * @package Drupal\simple_redirect
 */
class SimpleRedirectSubscriber implements EventSubscriberInterface {

  /**
   * Constructor.
   */
  public function __construct() {

  }

  /**
   * {@inheritdoc}
   */
  static function getSubscribedEvents() {
    $events['kernel.request'] = ['onKernalRequestSimpleRedirect'];

    return $events;
  }

  /**
   * This method is called whenever the kernel.request event is
   * dispatched.
   *
   * @param GetResponseEvent $event
   */
  public function onKernalRequestSimpleRedirect(GetResponseEvent $event) {
    $request = clone $event->getRequest();

    $url = $request->getPathInfo();

    $query = \Drupal::database()->select('simple_redirect', 's');
    $query->fields('s', ['sr_id']);
    $query->fields('s', ['sr_from']);
    $query->fields('s', ['sr_to']);
    $query->condition('s.sr_from', $url, '=');
    $simple_redirects = $query->execute()->fetchAll();
    if (!empty($simple_redirects)) {
      $url = \Drupal::pathValidator()->getUrlIfValidWithoutAccessCheck($simple_redirects[0]->sr_to);
      $url->setAbsolute();
      $redirect = $url->toString();

      $response = new RedirectResponse($redirect);
      $event->setResponse($response);
    }
  }

}
