<?php

/**
 * @file
 * Contains \Drupal\simple_redirect\Form\SimpleRedirectAdd.
 */

namespace Drupal\simple_redirect\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\simple_redirect\SimpleRedirectValidate;
use Symfony\Component\HttpFoundation\RedirectResponse;

/**
 * Class SimpleRedirectAdd.
 *
 * @package Drupal\simple_redirect\Form
 */
class SimpleRedirectAdd extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'simple_redirect_add';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['simple_redirect'] = [
      '#type' => 'fieldset',
      '#title' => t('Add a Simple Redirect'),
      '#collapsible' => FALSE,
      '#collapsed' => FALSE,
    ];
    $form['simple_redirect']['simple_redirect_from'] = [
      '#type' => 'textfield',
      '#title' => $this->t('From Url'),
      '#maxlength' => 64,
      '#size' => 64,
      '#description' => 'Enter the url from which to redirect Ex: node/1',
    ];
    $form['simple_redirect']['simple_redirect_to'] = [
      '#type' => 'textfield',
      '#title' => $this->t('To Url'),
      '#maxlength' => 64,
      '#size' => 64,
      '#description' => 'Enter the url to which this should redirect Ex: node/2',
    ];
    $form['simple_redirect']['simple_redirect_add'] = [
      '#type' => 'submit',
      '#value' => $this->t('Add'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    $from = $form_state->getValue('simple_redirect_from');
    $to = $form_state->getValue('simple_redirect_to');
    // Validate valid url and non empty url.
    SimpleRedirectValidate::validateSimpleRedirectUrl($form_state, $from, $to);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $fields = array(
      'sr_from' => $form_state->getValue('simple_redirect_from'),
      'sr_to' => $form_state->getValue('simple_redirect_to'),
    );
    $query = \Drupal::database()->insert('simple_redirect')
        ->fields($fields);
    $query->execute();

    $url = \Drupal::pathValidator()->getUrlIfValidWithoutAccessCheck('/admin/config/simple-redirect');
    $url->setAbsolute();
    $redirect = $url->toString();
    (new RedirectResponse($redirect))->send();
  }

}
