<?php

/**
 * @file
 * Contains \Drupal\simple_redirect\Form\SimpleRedirectDeleteConfirmForm.
 */

namespace Drupal\simple_redirect\Form;

use Drupal\Core\Form\ConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\simple_redirect\SimpleRedirectServiceInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a confirm form before ending users session.
 */
class SimpleRedirectDeleteConfirmForm extends ConfirmFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'simple_redirect_delete_confirm_form';
  }

  /**
   * {@inheritdoc}
   */
  public function getQuestion() {
    return $this->t('Sure to delete..!');
  }

  /**
   * {@inheritdoc}
   */
  public function getConfirmText() {
    return $this->t('Delete..');
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl() {
    return new Url('simple_redirect.simple_redirect_list');
  }

  /**
   * {@inheritdoc}
   *
   * @param integer $uid
   *   An user id.
   */
  public function buildForm(array $form, FormStateInterface $form_state, $uid = '') {
    $form['simple_redirect'] = [
      '#markup' => t("Delete..!"),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $sid = \Drupal::request()->attributes->get('sid');
    $query = \Drupal::database()->delete('simple_redirect')
      ->condition('sr_id', $sid);
    $query->execute();

    $form_state->setRedirectUrl($this->getCancelUrl());
  }
}
