<?php

/**
 * @file
 * Contains \Drupal\simple_redirect\Form\SimpleRedirectEditForm.
 */

namespace Drupal\simple_redirect\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\HttpFoundation\RedirectResponse;

/**
 * Class SimpleRedirectEditForm.
 *
 * @package Drupal\simple_redirect\Form
 */
class SimpleRedirectEditForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'simple_redirect_edit_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $sid = \Drupal::request()->attributes->get('sid');
    $query = \Drupal::database()->select('simple_redirect', 's');
    $query->fields('s', ['sr_id']);
    $query->fields('s', ['sr_from']);
    $query->fields('s', ['sr_to']);
    $query->condition('s.sr_id', $sid, '=');
    $results = $query->execute()->fetchAll();
    $form['simple_redirect_id'] = array(
      '#type' => 'hidden',
      '#value' => $results[0]->sr_id,
    );
    $form['simple_redirect_from'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('Simple Redirect From'),
      '#maxlength' => 64,
      '#size' => 64,
      '#default_value' => $results[0]->sr_from,
    );
    $form['simple_redirect_to'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('Simple Redirect To'),
      '#maxlength' => 64,
      '#size' => 64,
      '#default_value' => $results[0]->sr_to,
    );
    $form['simple_redirect_edit'] = array(
      '#type' => 'submit',
      '#value' => $this->t('Update form'),
    );

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $fields = array(
      'sr_from' => $form_state->getValue('simple_redirect_from'),
      'sr_to' => $form_state->getValue('simple_redirect_to'),
    );
    $query = \Drupal::database()->update('simple_redirect')
      ->fields($fields)
      ->condition('sr_id', $form_state->getValue('simple_redirect_id'));
    $query->execute();

    $url = \Drupal::pathValidator()->getUrlIfValidWithoutAccessCheck('/admin/config/simple-redirect');
    $url->setAbsolute();
    $redirect = $url->toString();
    (new RedirectResponse($redirect))->send();
  }

}
