<?php

/**
 * @file
 * Contains \Drupal\simple_redirect\Form\SimpleRedirectList.
 */

namespace Drupal\simple_redirect\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Link;
use Drupal\Core\Url;
use Symfony\Component\HttpFoundation\RedirectResponse;

/**
 * Class SimpleRedirectList.
 *
 * @package Drupal\simple_redirect\Form
 */
class SimpleRedirectList extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'simple_redirect_list';
  }

  function sss(array $element, FormStateInterface $form_state) {
    (new RedirectResponse('/admin/config/simple-redirect-add'))->send();
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['simple_redirect']['add'] = array(
      '#type' => 'link',
      '#title' => $this->t('Add'),
      '#attributes' => array(
        'class' => array('button', 'button--primary'),
      ),
      '#url' => Url::fromRoute('simple_redirect.simple_redirect_add'),
    );

    $query = \Drupal::database()->select('simple_redirect', 's');
    $query->fields('s', ['sr_id']);
    $query->fields('s', ['sr_from']);
    $query->fields('s', ['sr_to']);
    $results = $query->execute()->fetchAll();
    $output = [];
    foreach ($results as $result) {
      $edit_url = Url::fromUserInput('/admin/config/simple-redirect/' . $result->sr_id . '/edit')
        ->setOptions(['attributes' => ['class' => ['button']]]);
      $delete_url = Url::fromUserInput('/admin/config/simple-redirect/' . $result->sr_id . '/delete')
        ->setOptions(['attributes' => ['class' => ['button']]]);
      $output[$result->sr_id] = [
        'sr_from' => $result->sr_from,
        'sr_to' => $result->sr_to,
        'edit' => Link::fromTextAndUrl(t('Edit'), $edit_url),
        'delete' => Link::fromTextAndUrl(t('Delete'), $delete_url),
      ];
    }
    $header = [
      'sr_from' => t('Redirect From'),
      'sr_to' => t('Redirect To'),
      'edit' => t('Edit'),
      'delete' => t('Delete'),
    ];
    $form['simple_redirect']['table'] = [
      '#type' => 'tableselect',
      '#header' => $header,
      '#options' => $output,
      '#empty' => t('No users found'),
    ];

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => 'Delete Selected',
      '#button_type' => 'primary',
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $delete_selected = $form_state->getValue('table');
    foreach ($delete_selected as $delete) {
      if (isset($delete)) {
        $query = \Drupal::database()->delete('simple_redirect')
          ->condition('sr_id', $delete);
        $query->execute();
      }
    }
  }

}
